Crate ezsp

Crate ezsp 

Host-side support for the EmberZNet Serial Protocol (EZSP).

EZSP is the protocol used by a host application processor to communicate with the EmberZNet PRO stack running on a Network Co-Processor (NCP). Commands are sent by the host and answered by the NCP; UART-based NCPs may additionally send asynchronous callbacks as they occur.

This crate provides typed EZSP frame headers, parameter structures, command/response traits, and transport-independent command traits. With the ashv2 feature enabled, it also provides a UART transport for EZSP over ASHv2.

Protocol details are documented by Silicon Labs in the Simplicity SDK EZSP Reference Guide.

This library is free software and is not affiliated with Silicon Labs.

Modules

apis_saltans
Integration with the apis-saltans Zigbee hardware traits.
ember
EmberZNet stack data types exposed through EZSP.
ezsp
EZSP-specific protocol identifiers and values.
parameters
Definitions of parameter structures used in the Ember ZNet Serial Protocol (EZSP).
uart
EZSP-UART transport built on ASHv2.

Structs

Builder
Builder for Ncp startup configuration.
Command
Low byte control field of the frame header when it represents a command.
Extended
Extended EZSP header used by protocol version 8 and newer.
Frame
A decoded EZSP frame.
HighByte
The extended frame control field of the frame header.
Legacy
Legacy EZSP header.
Ncp
Host-side helper for an EZSP Network Co-Processor.
Scans
Aggregates scan callbacks until the matching scanComplete callback arrives.

Enums

Callback
Callback parameters grouped by parameter namespace.
CallbackType
Callback types.
Connection
Connection status of transport layer.
Error
An error that can occur when communicating with an NCP.
FormatVersion
Frame Format Version.
Header
EZSP header formats.
LowByte
The low byte of a frame header.
Message
Messages exchanged with the NCP event handler.
Parameters
Parameters parameters grouped by parameter namespace.
Response
Response parameters grouped by parameter namespace.
SleepMode
Sleep mode states.
SourceRouteDiscoveryMode
Discovery mode for source routes.
ValueError
Invalid values.

Constants

MAX_HEADER_SIZE
Maximum encoded EZSP header size in bytes.
MAX_PARAMETER_SIZE
Largest parameter body size handled by this implementation.
MIN_NON_LEGACY_VERSION
Minimum EZSP protocol version that uses the extended header format.

Traits

Binding
The Binding trait provides an interface for the binding table.
Bootloader
The Bootloader trait provides an interface for the bootloader features.
Cbke
The Cbke trait provides an interface for the Certificate Based Key Exchange features.
Configuration
The Configuration trait provides an interface for the configuration commands.
ConfigurationExt
Extension trait for retrieving all configuration values.
Displayable
Extension trait for converting a type into a displayable form.
Ezsp
Convenience trait for implementors of the full EZSP command surface.
GetValueExt
Extensions trait for the GetValue command.
GreenPower
The GreenPower trait provides an interface for the Green Power features.
Messaging
The Messaging trait provides an interface for the messaging features.
Mfglib
The Mfglib trait provides an interface for the Manufacturing and Functional Test Library (MfgLib) test routines.
Networking
The Networking trait provides an interface for the networking features.
Parsable
A trait for parsing parameters from a little-endian stream given their frame ID.
PolicyExt
Extension trait for retrieving all policy values.
ProxyTable
The ProxyTable trait provides an interface for the proxy table.
Security
The Security trait provides an interface for the security features.
SinkTable
The SinkTable trait provides an interface for the sink table.
TokenInterface
The TokenInterface trait provides an interface for the token interface.
Transport
A connection to an EZSP-capable Network Co-Processor.
TrustCenter
The TrustCenter trait provides an interface for the Trust Center features.
Utilities
The Utilities trait provides an interface for the utilities.
Wwah
The Wwah trait provides an interface for the Work With All Hubs (WWAH) protocol.
Zll
The Zll trait provides an interface for the Zigbee Light Link (ZLL) protocol.

Type Aliases

Result
A specialized Result type for this crate.