Frame

Struct Frame 

pub struct Frame { /* private fields */ }
Zigbee APS frame parameters.

Implementations

Source

impl Frame

pub const fn new( profile_id: u16, cluster_id: u16, source_endpoint: u8, destination_endpoint: u8, options: Options, group_id: u16, sequence: u8, ) -> Self

Create a new APS frame.

pub const fn profile_id(&self) -> u16

Return the application profile ID that describes the format of the message.

pub const fn cluster_id(&self) -> u16

Return the cluster ID for this message.

pub const fn source_endpoint(&self) -> u8

Return the source endpoint.

pub const fn destination_endpoint(&self) -> u8

Return the destination endpoint.

pub const fn options(&self) -> Options

Return a list of options.

pub const fn group_id(&self) -> u16

Return the group ID for this message if it is a multicast mode.

pub const fn set_group_id(&mut self, group_id: u16)

Sets the raw APS group ID field.

For multicast frames this identifies the destination group. Fragmented frames overload the field with the fragment index in the low byte and block information in the high byte. This method does not modify Options::FRAGMENT or validate that encoding; use Frame::set_first_fragment or Frame::set_followup_fragment when constructing fragmented frames.

pub const fn sequence(&self) -> u8

Return the sequence number.

pub const fn set_sequence(&mut self, sequence: u8)

Set the APS sequence number.

pub fn enable_retry(&mut self)

Enable APS retry for this frame.

pub const fn fragmentation(&self) -> Option<(u8, Option<u8>)>

Return fragmentation information if the message is fragmented.

Returns
  • Some((index, Some(total_fragments))) if this is the first fragment, where index is 0.
  • Some((index, None)) if this is a subsequent fragment.
  • None if the message is not fragmented.
pub fn set_first_fragment(&mut self, blocks: u8)

Mark this frame as the first fragment of a fragmented APS message.

pub fn set_followup_fragment(&mut self, index: NonZero<u8>)

Mark this frame as a follow-up fragment of a fragmented APS message.

pub fn clear_fragmentation(&mut self)

Removes APS fragmentation metadata from this frame.