SimEeprom

Enum SimEeprom 

pub enum SimEeprom {
    ErasePageGreen,
    ErasePageRed,
    Full,
    Init1Failed,
    Init2Failed,
    Init3Failed,
}
Ember simulated EEPROM status.

Variants



ErasePageGreen

The Simulated EEPROM is telling the application that there is at least one flash page to be erased.

The GREEN status means the current page has not filled above the ERASE_CRITICAL_THRESHOLD. The application should call the function halSimEepromErasePage when it can to erase a page.



ErasePageRed

The Simulated EEPROM is telling the application that there is at least one flash page to be erased.

The RED status means the current page has filled above the ERASE_CRITICAL_THRESHOLD. Due to the shrinking availability of write space, there is a danger of data loss. The application must call the function halSimEepromErasePage as soon as possible to erase a page.



Full

The Simulated EEPROM has run out of room to write any new data and the data trying to be set has been lost.

This error code is the result of ignoring the SIM_EEPROM_ERASE_PAGE_RED error code. The application must call the function halSimEepromErasePage to make room for any further calls to set a token.



Init1Failed

Attempt 1 to initialize the Simulated EEPROM has failed.

This failure means the information already stored in Flash (or a lack thereof), is fatally incompatible with the token information compiled into the code image being run.



Init2Failed

Attempt 2 to initialize the Simulated EEPROM has failed.

This failure means Attempt 1 failed, and the token system failed to properly reload default tokens and reset the Simulated EEPROM.



Init3Failed

Attempt 3 to initialize the Simulated EEPROM has failed.

This failure means one or both of the tokens TOKEN_MFG_NVDATA_VERSION or TOKEN_STACK_NVDATA_VERSION were incorrect.