Status

Enum Status 

pub enum Status {
Show 60 variants Success, ErrFatal, BadArgument, Eeprom(Eeprom), NoBuffers, Serial(Serial), Mac(Mac), SimEeprom(SimEeprom), Err(Err), DeliveryFailed, BindingIndexOutOfRange, AddressTableIndexOutOfRange, InvalidBindingIndex, InvalidCall, CostNotKnown, MaxMessageLimitReached, MessageTooLong, BindingIsActive, AddressTableEntryIsActive, Adc(Adc), SleepInterrupted, Phy(Phy), NetworkUp, NetworkDown, NotJoined, JoinFailed, InvalidSecurityLevel, MoveFailed, CannotJoinAsRouter, NodeIdChanged, PanIdChanged, NetworkOpened, NetworkClosed, NoBeacons, ReceivedKeyInTheClear, NoNetworkKeyReceived, NoLinkKeyReceived, PreconfiguredKeyRequired, KeyInvalid, NetworkBusy, InvalidEndpoint, BindingHasChanged, InsufficientRandomData, ApsEncryptionError, SecurityStateNotSet, SourceRouteFailure, ManyToOneRouteFailure, StackAndHardwareMismatch, IndexOutOfRange, KeyTableInvalidAddress, TableFull, LibraryNotPresent, TableEntryErased, SecurityConfigurationInvalid, TooSoonForSwitchKey, SignatureVerifyFailure, OperationInProgress, KeyNotAuthorized, SecurityDataInvalid, Application(Application),
}
Variants



Success

The generic ‘no error’ message.



ErrFatal

The generic ‘fatal error’ message.



BadArgument

An invalid value was passed as an argument to a function.



Eeprom(Eeprom)

EEPROM status.



NoBuffers

There are no more buffers.



Serial(Serial)

Serial status.



Mac(Mac)

MAC status.



SimEeprom(SimEeprom)

Simulated EEPROM status.



Err(Err)

Erroneous messages.



DeliveryFailed

The APS layer attempted to send or deliver a message, but it failed.



BindingIndexOutOfRange

This binding index is out of range of the current binding table.



AddressTableIndexOutOfRange

This address table index is out of range for the current address table.



InvalidBindingIndex

An invalid binding table index was given to a function.



InvalidCall

The API call is not allowed given the current state of the stack.



CostNotKnown

The link cost to a node is not known.



MaxMessageLimitReached

The maximum number of in-flight messages (i.e. EMBER_APS_UNICAST_MESSAGE_COUNT) has been reached.



MessageTooLong

The message to be transmitted is too big to fit into a single over-the-air packet.



BindingIsActive

The application is trying to delete or overwrite a binding that is in use.



AddressTableEntryIsActive

The application is trying to overwrite an address table entry that is in use.



Adc(Adc)

ADC status.



SleepInterrupted

Sleeping (for a duration) has been abnormally interrupted and exited prematurely.



Phy(Phy)

PHY status.



NetworkUp

The stack software has completed initialization and is ready to send and receive packets over the air.



NetworkDown

The network is not operating.



NotJoined

The node has not joined a network.



JoinFailed

An attempt to join a network failed.



InvalidSecurityLevel

The chosen security level (the value of EMBER_SECURITY_LEVEL) is not supported by the stack.



MoveFailed

After moving, a mobile node’s attempt to re-establish contact with the network failed.



CannotJoinAsRouter

An attempt to join as a router failed due to a Zigbee versus Zigbee Pro incompatibility.

Zigbee devices joining Zigbee Pro networks (or vice versa) must join as End Devices, not Routers.



NodeIdChanged

The local node ID has changed.

The application can obtain the new node ID by calling emberGetNodeId().



PanIdChanged

The local PAN ID has changed.

The application can obtain the new PAN ID by calling emberGetPanId().



NetworkOpened

The network has been opened for joining.



NetworkClosed

The network has been closed for joining.



NoBeacons

An attempt to join or rejoin the network failed because no router beacons could be heard by the joining node.



ReceivedKeyInTheClear

An attempt was made to join a Secured Network using a pre-configured key, but the Trust Center sent back a Network Key in-the-clear when an encrypted Network Key was required.



NoNetworkKeyReceived

An attempt was made to join a Secured Network, but the device did not receive a Network Key.



NoLinkKeyReceived

After a device joined a Secured Network, a Link Key was requested but no response was ever received.



PreconfiguredKeyRequired

An attempt was made to join a Secured Network without a pre-configured key, but the Trust Center sent encrypted data using a pre-configured key.



KeyInvalid

The passed key data is not valid.

A key of all zeros or all F’s are reserved values and cannot be used.



NetworkBusy

A message cannot be sent because the network is currently overloaded.



InvalidEndpoint

The application tried to send a message using an endpoint that it has not defined.



BindingHasChanged

The application tried to use a binding that has been remotely modified and the change has not yet been reported to the application.



InsufficientRandomData

An attempt to generate random bytes failed because of insufficient random data from the radio.



ApsEncryptionError

There was an error in trying to encrypt at the APS Level.

This could result from either an inability to determine the long address of the recipient from the short address (no entry in the binding table) or there is no link key entry in the table associated with the destination, or there was a failure to load the correct key into the encryption core.



SecurityStateNotSet

There was an attempt to form or join a network with security without calling emberSetInitialSecurityState() first.



SourceRouteFailure

A Zigbee route error command frame was received indicating that a source routed message from this node failed en route



ManyToOneRouteFailure

A Zigbee route error command frame was received indicating that a message sent to this node along a many-to-one route failed en route.

The route error frame was delivered by an ad-hoc search for a functioning route.



StackAndHardwareMismatch

A critical and fatal error indicating that the version of the stack trying to run does not match with the chip it is running on.

The software (stack) on the chip must be replaced with software that is compatible with the chip.



IndexOutOfRange

An index was passed into the function that was larger than the valid range.



KeyTableInvalidAddress

There was an attempt to set an entry in the key table using an invalid long address.

An entry cannot be set using either the local device’s or Trust Center’s IEEE address. Or an entry already exists in the table with the same IEEE address. An Address of all zeros or all F’s are not valid addresses in 802.15.4.



TableFull

There are no empty entries left in the table.



LibraryNotPresent

The requested function cannot be executed because the library that contains the necessary functionality is not present.



TableEntryErased

The requested table entry has been erased and contains no valid data.



SecurityConfigurationInvalid

There was an attempt to set a security configuration that is not valid given the other security settings.



TooSoonForSwitchKey

There was an attempt to broadcast a key switch too quickly after broadcasting the next network key.

The Trust Center must wait at least a period equal to the broadcast timeout so that all routers have a chance to receive the broadcast of the new network key.



SignatureVerifyFailure

The received signature corresponding to the message that was passed to the CBKE Library failed verification, it is not valid.



OperationInProgress

The stack accepted the command and is currently processing the request.

The results will be returned via an appropriate handler.



KeyNotAuthorized

The message could not be sent because the link key corresponding to the destination is not authorized for use in APS data messages.

APS Commands (sent by the stack) are allowed. To use it for encryption of APS data messages it must be authorized using a key agreement protocol (such as CBKE).



SecurityDataInvalid

The security data provided was not valid, or an integrity check failed.



Application(Application)

Application status.