#[repr(u8)]pub enum Type {
UnknownDevice = 0,
Coordinator = 1,
Router = 2,
EndDevice = 3,
SleepyEndDevice = 4,
}Expand description
Ember node type.
Variants
UnknownDevice = 0
Device is not joined.
Coordinator = 1
Will relay messages and can act as a parent to other nodes.
Router = 2
Will relay messages and can act as a parent to other nodes.
EndDevice = 3
Communicates only with its parent and will not relay messages.
SleepyEndDevice = 4
An end device whose radio can be turned off to save power.
The application must poll to receive messages.