pub enum LowByte {
Command(Command),
Response(Response),
}Expand description
The low byte of a frame header.
Variants
Implementations
Sourceimpl LowByte
impl LowByte
Sourcepub const fn is_command(self) -> bool
pub const fn is_command(self) -> bool
Returns true if the low byte is a command else false.
Sourcepub const fn is_response(self) -> bool
pub const fn is_response(self) -> bool
Returns true if the low byte is a response else false.