pub struct BootloadTransmitComplete { /* private fields */ }Expand description
Handler parameters.
Implementations
Sourceimpl Handler
impl Handler
Sourcepub fn ack_received(&self) -> Result<bool, Error>
pub fn ack_received(&self) -> Result<bool, Error>
Returns true if an ACK was received from the destination or false if no ACK was received.
Errors
Returns an Error if the status is not Status::Success or Status::DeliveryFailed.