IncomingManyToOneRouteRequest

Struct IncomingManyToOneRouteRequest 

pub struct IncomingManyToOneRouteRequest { /* private fields */ }
Handler parameters.

Implementations

Source

impl Handler

pub const fn source(&self) -> NodeId

The short id of the concentrator.

pub const fn long_id(&self) -> Eui64

The EUI64 of the concentrator.

pub const fn cost(&self) -> u8

The path cost to the concentrator.

The cost may decrease as additional route request packets for this discovery arrive, but the callback is made only once.