ZigbeeKeyEstablishment

Struct ZigbeeKeyEstablishment 

pub struct ZigbeeKeyEstablishment { /* private fields */ }
Handler parameters.

Implementations

Source

impl Handler

pub fn partner(&self) -> Result<Eui64, Result<Status, u8>>

This is the IEEE address of the partner that the device successfully established a key with.

Errors

Returns an error if the key establishment was not successful, containing either the status indicating what was established or why the key establishment failed.

pub fn status(&self) -> Result<Status, u8>

This is the status indicating what was established or why the key establishment failed.

Errors

Returns an error if the status is invalid.