GetValueExt

Trait GetValueExt 

pub trait GetValueExt {
    // Required method
    fn get_ember_version(
        &mut self,
    ) -> impl Future<Output = Result<Result<EmberVersion, TryFromSliceError>, Error>> + Send;
}
Extensions trait for the GetValue command.

This trait provides an additional method to read certain values from the NCP,

Required Methods

fn get_ember_version( &mut self, ) -> impl Future<Output = Result<Result<EmberVersion, TryFromSliceError>, Error>> + Send

Reads a value from the NCP but passes an extra argument specific to the value being retrieved.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> GetValueExt for T
where T: Configuration + Send,