Host-side support for the EmberZNet Serial Protocol (EZSP).
EZSP is the protocol used by a host application processor to communicate
with the EmberZNet PRO stack running on a Network Co-Processor (NCP).
Commands are sent by the host and answered by the NCP; UART-based NCPs may
additionally send asynchronous callbacks as they occur.
This crate provides typed EZSP frame headers, parameter structures,
command/response traits, and transport-independent command traits. With the
ashv2 feature enabled, it also provides a UART transport for EZSP over
ASHv2.
Protocol details are documented by Silicon Labs in the Simplicity SDK EZSP Reference Guide.
This library is free software and is not affiliated with Silicon Labs.
Modules
- apis_
saltans - Integration with the
apis-saltansZigbee hardware traits. - ember
EmberZNetstack data types exposed through EZSP.- ezsp
- EZSP-specific protocol identifiers and values.
- parameters
- Definitions of parameter structures used in the
Ember ZNet Serial Protocol(EZSP). - uart
- EZSP-UART transport built on
ASHv2.
Structs
- Builder
- Builder for
Ncpstartup configuration. - Command
- Low byte control field of the frame header when it represents a command.
- Extended
- Extended EZSP header used by protocol version 8 and newer.
- Frame
- A decoded EZSP frame.
- High
Byte - The extended frame control field of the frame header.
- Legacy
- Legacy EZSP header.
- Ncp
- Host-side helper for an EZSP Network Co-Processor.
- Scans
- Aggregates scan callbacks until the matching
scanCompletecallback arrives.
Enums
- Callback
- Callback parameters grouped by parameter namespace.
- Callback
Type - Callback types.
- Connection
- Connection status of transport layer.
- Error
- An error that can occur when communicating with an NCP.
- Format
Version - Frame Format Version.
- Header
- EZSP header formats.
- LowByte
- The low byte of a frame header.
- Message
- Messages exchanged with the NCP event handler.
- Parameters
- Parameters parameters grouped by parameter namespace.
- Response
- Response parameters grouped by parameter namespace.
- Sleep
Mode - Sleep mode states.
- Source
Route Discovery Mode - Discovery mode for source routes.
- Value
Error - Invalid values.
Constants
- MAX_
HEADER_ SIZE - Maximum encoded EZSP header size in bytes.
- MAX_
PARAMETER_ SIZE - Largest parameter body size handled by this implementation.
- MIN_
NON_ LEGACY_ VERSION - Minimum EZSP protocol version that uses the extended header format.
Traits
- Binding
- The
Bindingtrait provides an interface for the binding table. - Bootloader
- The
Bootloadertrait provides an interface for the bootloader features. - Cbke
- The
Cbketrait provides an interface for the Certificate Based Key Exchange features. - Configuration
- The
Configurationtrait provides an interface for the configuration commands. - Configuration
Ext - Extension trait for retrieving all configuration values.
- Displayable
- Extension trait for converting a type into a displayable form.
- Ezsp
- Convenience trait for implementors of the full EZSP command surface.
- GetValue
Ext - Extensions trait for the
GetValuecommand. - Green
Power - The
GreenPowertrait provides an interface for the Green Power features. - Messaging
- The
Messagingtrait provides an interface for the messaging features. - Mfglib
- The
Mfglibtrait provides an interface for the Manufacturing and Functional Test Library (MfgLib) test routines. - Networking
- The
Networkingtrait provides an interface for the networking features. - Parsable
- A trait for parsing parameters from a little-endian stream given their frame ID.
- Policy
Ext - Extension trait for retrieving all policy values.
- Proxy
Table - The
ProxyTabletrait provides an interface for the proxy table. - Security
- The
Securitytrait provides an interface for the security features. - Sink
Table - The
SinkTabletrait provides an interface for the sink table. - Token
Interface - The
TokenInterfacetrait provides an interface for the token interface. - Transport
- A connection to an EZSP-capable Network Co-Processor.
- Trust
Center - The
TrustCentertrait provides an interface for the Trust Center features. - Utilities
- The
Utilitiestrait provides an interface for the utilities. - Wwah
- The
Wwahtrait provides an interface for the Work With All Hubs (WWAH) protocol. - Zll
- The
Zlltrait provides an interface for the Zigbee Light Link (ZLL) protocol.