pub struct ZigbeeKeyEstablishment { /* private fields */ }Expand description
Handler parameters.
Implementations
Sourceimpl Handler
impl Handler
Sourcepub fn partner(&self) -> Result<Eui64, Result<Status, u8>>
pub fn partner(&self) -> Result<Eui64, Result<Status, u8>>
This is the IEEE address of the partner that the device successfully established a key with.
Errors
Returns an error if the key establishment was not successful, containing either the status indicating what was established or why the key establishment failed.