pub trait ProxyTable {
// Required methods
fn get_entry(
&mut self,
proxy_index: u8,
) -> impl Future<Output = Result<TableEntry, Error>> + Send;
fn lookup(
&mut self,
addr: Address,
) -> impl Future<Output = Result<u8, Error>> + Send;
fn process_gp_pairing(
&mut self,
options: u32,
addr: Address,
comm_mode: u8,
sink_network_address: u16,
sink_group_id: u16,
assigned_alias: u16,
sink_ieee_address: [u8; 8],
gpd_key: Data,
gpd_security_frame_counter: u32,
forwarding_radius: u8,
) -> impl Future<Output = Result<bool, Error>> + Send;
}Expand description
The ProxyTable trait provides an interface for the proxy table.
Required Methods
Sourcefn get_entry(
&mut self,
proxy_index: u8,
) -> impl Future<Output = Result<TableEntry, Error>> + Send
fn get_entry( &mut self, proxy_index: u8, ) -> impl Future<Output = Result<TableEntry, Error>> + Send
Retrieves the proxy table entry stored at the passed index.
Sourcefn lookup(
&mut self,
addr: Address,
) -> impl Future<Output = Result<u8, Error>> + Send
fn lookup( &mut self, addr: Address, ) -> impl Future<Output = Result<u8, Error>> + Send
Finds the index of the passed address in the gp table.
Sourcefn process_gp_pairing(
&mut self,
options: u32,
addr: Address,
comm_mode: u8,
sink_network_address: u16,
sink_group_id: u16,
assigned_alias: u16,
sink_ieee_address: [u8; 8],
gpd_key: Data,
gpd_security_frame_counter: u32,
forwarding_radius: u8,
) -> impl Future<Output = Result<bool, Error>> + Send
fn process_gp_pairing( &mut self, options: u32, addr: Address, comm_mode: u8, sink_network_address: u16, sink_group_id: u16, assigned_alias: u16, sink_ieee_address: [u8; 8], gpd_key: Data, gpd_security_frame_counter: u32, forwarding_radius: u8, ) -> impl Future<Output = Result<bool, Error>> + Send
Update the GP Proxy table based on a GP pairing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".